=======
hotsoss
=======


.. image:: https://img.shields.io/pypi/v/hotsoss.svg
        :target: https://pypi.python.org/pypi/hotsoss

.. image:: https://img.shields.io/travis/hover2pi/hotsoss.svg
        :target: https://travis-ci.org/hover2pi/hotsoss

.. image:: https://readthedocs.org/projects/hotsoss/badge/?version=latest
        :target: https://hotsoss.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/coveralls/github/hover2pi/hotsoss.svg
        :target: https://coveralls.io/github/hover2pi/hotsoss

.. image:: https://pyup.io/repos/github/hover2pi/hotsoss/shield.svg
     :target: https://pyup.io/repos/github/hover2pi/hotsoss/
     :alt: Updates


Helpful Organizational Tools for SOSS
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Authors: Joe Filippazzo

This pure Python 3.5+ package contains helpful reference file
organizational tools and data visulaization functions that may
be useful in analyzing observations from the Single Object Slitless
Spectroscopy (SOSS) mode of the Near-Infrared Imager and Slitless
Spectrograph (NIRISS) instrument onboard the James Webb Space
Telescope (JWST).

Additional resources:

- `Full documentation <https://hotsoss.readthedocs.io/en/latest/>`_
- `Build history <https://travis-ci.org/hover2pi/hotsoss>`_
